import { TaskEnum, TaskStatusEnum } from "@/const"
import { AlertOutlined, SearchOutlined } from "@ant-design/icons"
import { PageContainer } from "@ant-design/pro-components"
import { useSize } from "ahooks";
import { Affix, Alert, Avatar, Badge, Button, Card, Flex, Input, List, Select, Space, Tag, Typography, theme } from "antd"
import { useEffect, useRef } from "react";

const data = Array.from({ length: 23 }).map((_, i) => ({
    // href: 'https://ant.design',
    title: `素材任务名称 ${i}`,
    avatar: `https://xsgames.co/randomusers/avatar.php?g=pixel&key=${i}`,
    description: '这是一条任务描述，XXXXXXXXXXXXXXXXXXXXXXXXXXXXX好长好长Ant Design, a design language',
    content:
        'We supply a series of design principles, practical patterns and high quality design resources (Sketch and Axure), to help people create their product prototypes beautifully and efficiently.',
}));
/**
 * 任务中心
 * @returns 
 */
const Task: React.FC = () => {

    const { useToken } = theme;
    const ref = useRef(null);
    const size = useSize(ref)
    const { token } = useToken();

    return <PageContainer>
        <Card
            style={{
                borderRadius: 8,
            }}
            bodyStyle={{
                paddingTop: 0,
                paddingLeft: 0,
                paddingRight: 0
            }}
            ref={ref}
        >
            <Space direction="vertical" style={{ width: '100%' }} size={0}>

                <Affix offsetTop={56}>
                    <div style={{ backgroundColor: token.colorBgBase, padding: token.paddingContentHorizontalLG, paddingBottom: 5, borderRadius: 8, borderBottom: `1px solid ${token.colorBorderSecondary}` }}>
                        <Space direction="vertical" style={{ width: '100%' }}>
                            <Space wrap>
                                <Input prefix={<SearchOutlined />} placeholder="搜索你感兴趣的悬赏任务" style={{ width: 300 }} />
                                <Alert
                                    style={{ padding: `4px 12px` }}
                                    type="warning"
                                    showIcon
                                    icon={<AlertOutlined />}
                                    message="官方公告：点击任务内的素材上传按钮完成任务，即有机会获取丰厚的奖励！"
                                />
                            </Space>
                            <Space>
                                <Select
                                    className="drawSelect"
                                    defaultValue="taskType"
                                    style={{ width: 100, padding: 0 }}
                                    bordered={false}
                                    options={[
                                        { value: 'taskType', label: '任务分类' },
                                        ...Object.keys(TaskEnum).map(key => ({ value: key, label: (TaskEnum as any)[key] }))
                                    ]}
                                />
                                <Select
                                    className="drawSelect"
                                    defaultValue="taskStatus"
                                    style={{ width: 100, padding: 0 }}
                                    bordered={false}
                                    options={[
                                        { value: 'taskStatus', label: '任务状态' },
                                        ...Object.keys(TaskStatusEnum).map(key => ({ value: key, label: (TaskStatusEnum as any)[key] }))
                                    ]}
                                />
                                <Select
                                    className="drawSelect"
                                    defaultValue="time"
                                    style={{ width: 180, padding: 0 }}
                                    bordered={false}
                                    options={[
                                        { value: 'time', label: '按任务发布时间排序' },
                                    ]}
                                />
                            </Space>
                        </Space>
                    </div>
                </Affix>

                <List
                    itemLayout="vertical"
                    size="large"
                    dataSource={data}
                    pagination={{
                        onChange: (page) => {
                            console.log(page);
                        },
                        pageSize: 10,
                    }}
                    renderItem={(item: any) => (
                        <List.Item
                            key={item.title}
                            extra={<Flex gap={20} style={{ height: '100%' }}>
                                <Flex style={{ width: size?.width ? `${size?.width / 2  - 200}px` : 300 }} vertical={true} align="center" justify="center">
                                    <span>素材制作要求：素材比例、素材尺寸、素材分辨率、素材大小</span>
                                    <Space>
                                        <Button type="link">素材示例</Button>
                                        <Button type="link">资源包下载</Button>
                                    </Space>
                                </Flex>
                                <Flex style={{ minWidth: 100, height: '100%' }} gap={10} vertical={true} align="center" justify="center">
                                    <Badge status="success" text="任务发布中" />
                                    <Tag color="error">结算：总消耗2%</Tag>
                                    <Button type="primary">提交素材</Button>
                                </Flex>
                            </Flex>}
                            actions={[
                                <span>发布时间：2023/10/01</span>,
                                <Space>
                                    <Tag color="success">游戏</Tag>
                                    <Tag color="processing">小说</Tag>
                                    <Tag color="error">error</Tag>
                                    <Tag color="warning">warning</Tag>
                                    <Tag color="default">default</Tag>
                                </Space>,
                            ]}
                        >
                            <List.Item.Meta
                                avatar={<Avatar src={item.avatar} style={{ backgroundColor: '#87d068' }} />}
                                title={<Space size={20}>
                                    <span>{item.title}</span>
                                    <Space size={4}><span style={{ color: 'red' }}>置顶</span>🆙</Space>
                                </Space>}
                                description={<Space direction="vertical" style={{ width: '100%' }} size={0}>
                                    {/* 有效时间 */}
                                    <Typography.Text type="secondary" ellipsis>任务有效时间：2023年10月01日~2023年10月31日</Typography.Text>
                                    {/* 任务描述 */}
                                    <Typography.Text type="secondary" ellipsis={{ tooltip: true }}>{item.description}</Typography.Text>
                                </Space>}
                            />
                            {item.content}
                        </List.Item>
                    )}
                />
            </Space>
        </Card>
    </PageContainer>
}

export default Task